{% ckan_extends %}

{% block skip %}
    {% if h.status_get_message() %}
        {% asset 'ckanext-status/main' %}
        <div id="status-bar">
            <div>
                {% if h.status_enable_html() %}
                    {{ h.status_get_message()|safe }}
                {% else %}
                    {{ h.status_get_message() }}
                {% endif %}
            </div>
            <div class="status-page-link">
                <a href="{{ h.url_for('status.index') }}">
                    see more on status page
                </a>
            </div>
        </div>
    {% endif %}
    {{ super() }}
{% endblock %}
